netapp_ontap.models.audit_schedule API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.audit_schedule`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AuditScheduleSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AuditSchedule object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `days GET POST PATCH`

    Specifies the day of the month schedule to rotate audit log. Leave empty for all.

  `hours GET POST PATCH`

    Specifies the hourly schedule to rotate audit log. Leave empty for all.

  `minutes GET POST PATCH`

    Specifies the minutes schedule to rotate the audit log.

  `months GET POST PATCH`

    Specifies the months schedule to rotate audit log. Leave empty for all.

  `weekdays GET POST PATCH`

    Specifies the weekdays schedule to rotate audit log. Leave empty for all.